@@ -76,12 +76,13 @@ class ModelSeeder(object):
 
         return formatters
 
-    def execute(self, using, inserted_entities, skip_if_exists=False):
+    def execute(self, using, inserted_entities, skip_if_exists=False, verbose=False):
         """
         Execute the stages entities to insert
         :param using:
         :param inserted_entities:
         :param skip_if_exists: if True, will not insert if the entity already exists
+        :param verbose: if True, will print the errors
         """
 
         def format_field(format, inserted_entities):
@@ -106,10 +107,13 @@ class ModelSeeder(object):
                 })
                 return obj.pk
             except django.db.utils.DataError as e:
-                print(e)
+                if verbose:
+                    print(e)
                 continue
 
             except django.db.utils.IntegrityError as e:
+                if verbose:
+                    print(e)
                 if not skip_if_exists:
                     continue
                 return
@@ -148,13 +152,14 @@ class Seeder(object):
         self.quantities[klass] = number
         self.orders.append(klass)
 
-    def execute(self, using=None, skip_if_exists=False):
+    def execute(self, using=None, skip_if_exists=False, verbose=False):
         """
         Populate the database using all the Entity classes previously added.
 
         :param using A Django database connection name
         :rtype: A list of the inserted PKs
         :param skip_if_exists: if True, will not insert if the entity already exists
+        :param verbose: if True, will print the errors
         """
         if not using:
             using = self.get_connection()
@@ -165,7 +170,8 @@ class Seeder(object):
             if klass not in inserted_entities:
                 inserted_entities[klass] = []
             for i in range(0, number):
-                entity = self.entities[klass].execute(using, inserted_entities, skip_if_exists=skip_if_exists)
+                entity = self.entities[klass].execute(using, inserted_entities, skip_if_exists=skip_if_exists,
+                                                      verbose=verbose)
                 if entity:
                     inserted_entities[klass].append(entity)
 
